@@ -21,7 +21,7 @@ use Date::Tolkien::Shire::Data qw{
 use Time::Local;
 
 our $ERROR;
-our $VERSION = '1.903_01';
+our $VERSION = '1.904_01';
 
 sub new {
     my ( $class, $date, %arg ) = @_;
@@ -725,7 +725,7 @@ rather than common weekday names.
 
 =head1 NOTE: YEAR CALCULATION
 
-L<http://www.glyphweb.com/arda/f/fourthage.html> references a letter sent by
+L<https://www.glyphweb.com/arda/f/fourthage.html> references a letter sent by
 Tolkien in 1958 in which he estimates approximately 6000 years have passed
 since the War of the Ring and the end of the Third Age.  (Thanks to Danny
 O'Brien from sending me this link).  I took this approximate as an exact
@@ -756,7 +756,7 @@ the two calendars, however.  Thus the last day of our year is sometimes
 Tolkien, J. R. R. I<Return of the King>.  New York: Houghton Mifflin Press,
 1955.
 
-L<http://www.glyphweb.com/arda/f/fourthage.html>
+L<https://www.glyphweb.com/arda/f/fourthage.html>
 
 =head1 BUGS
 
